@@ -1,7 +1,7 @@
 // synthv1.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -41,10 +41,10 @@
 
 
 #ifdef CONFIG_DEBUG_0
-#include <stdio.h>
+#include <cstdio>
 #endif
 
-#include <string.h>
+#include <cstring>
 
 
 //-------------------------------------------------------------------------
