@@ -1,7 +1,7 @@
 // synthv1widget_programs.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -24,35 +24,63 @@
 #include "synthv1_programs.h"
 #include "synthv1_config.h"
 
+#include <QItemDelegate>
 #include <QHeaderView>
-
 #include <QSpinBox>
 #include <QLineEdit>
 #include <QComboBox>
 
 
+//----------------------------------------------------------------------------
+// synthv1widget_programs::ItemDelegate -- Custom (tree) list item delegate.
+
+class synthv1widget_programs::ItemDelegate : public QItemDelegate
+{
+public:
+
+	// ctor.
+	ItemDelegate(QObject *pParent = 0);
+
+	// QItemDelegate interface...
+	QSize sizeHint(
+		const QStyleOptionViewItem& option,
+		const QModelIndex& index) const;
+
+	QWidget *createEditor(QWidget *pParent,
+		const QStyleOptionViewItem& option,
+		const QModelIndex& index) const;
+
+	void setEditorData(QWidget *pEditor,
+		const QModelIndex& index) const;
+
+	void setModelData(QWidget *pEditor,
+		QAbstractItemModel *pModel,
+		const QModelIndex& index) const;
+};
+
+
 //----------------------------------------------------------------------------
 // synthv1widget_programs_item_delegate -- Custom (tree) list item delegate.
 
 // ctor.
-synthv1widget_programs_item_delegate::synthv1widget_programs_item_delegate (
-	QObject *pParent ) : QItemDelegate(pParent)
+synthv1widget_programs::ItemDelegate::ItemDelegate ( QObject *pParent )
+	: QItemDelegate(pParent)
 {
 }
 
 
 // QItemDelegate interface...
-QSize synthv1widget_programs_item_delegate::sizeHint (
+QSize synthv1widget_programs::ItemDelegate::sizeHint (
 	const QStyleOptionViewItem& option, const QModelIndex& index ) const
 {
 	return QItemDelegate::sizeHint(option, index) + QSize(4, 4);
 }
 
 
-QWidget *synthv1widget_programs_item_delegate::createEditor ( QWidget *pParent,
+QWidget *synthv1widget_programs::ItemDelegate::createEditor ( QWidget *pParent,
 	const QStyleOptionViewItem& /*option*/, const QModelIndex& index ) const
 {
-	QWidget *pEditor = NULL;
+	QWidget *pEditor = nullptr;
 
 	switch (index.column()) {
 	case 0: // Data.
@@ -88,7 +116,7 @@ QWidget *synthv1widget_programs_item_delegate::createEditor ( QWidget *pParent,
 	}
 
 #ifdef CONFIG_DEBUG_0
-	qDebug("synthv1widget_programs_item_delegate::createEditor(%p, %d, %d) = %p",
+	qDebug("synthv1widget_programs::ItemDelegate::createEditor(%p, %d, %d) = %p",
 		pParent, index.row(), index.column(), pEditor);
 #endif
 
@@ -96,11 +124,11 @@ QWidget *synthv1widget_programs_item_delegate::createEditor ( QWidget *pParent,
 }
 
 
-void synthv1widget_programs_item_delegate::setEditorData (
+void synthv1widget_programs::ItemDelegate::setEditorData (
 	QWidget *pEditor, const QModelIndex& index ) const
 {
 #ifdef CONFIG_DEBUG_0
-	qDebug("synthv1widget_programs_item_delegate::setEditorData(%p, %d, %d)",
+	qDebug("synthv1widget_programs::ItemDelegate::setEditorData(%p, %d, %d)",
 		pEditor, index.row(), index.column());
 #endif
 
@@ -137,11 +165,11 @@ void synthv1widget_programs_item_delegate::setEditorData (
 }
 
 
-void synthv1widget_programs_item_delegate::setModelData ( QWidget *pEditor,
+void synthv1widget_programs::ItemDelegate::setModelData ( QWidget *pEditor,
 	QAbstractItemModel *pModel,	const QModelIndex& index ) const
 {
 #ifdef CONFIG_DEBUG_0
-	qDebug("synthv1widget_programs_item_delegate::setModelData(%p, %d, %d)",
+	qDebug("synthv1widget_programs::ItemDelegate::setModelData(%p, %d, %d)",
 		pEditor, index.row(), index.column());
 #endif
 
@@ -203,14 +231,14 @@ synthv1widget_programs::synthv1widget_programs ( QWidget *pParent )
 	QTreeWidget::setSelectionMode(QAbstractItemView::SingleSelection);
 
 	QHeaderView *pHeaderView = QTreeWidget::header();
-#if QT_VERSION < 0x050000
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 	pHeaderView->setResizeMode(QHeaderView::ResizeToContents);
 #else
 	pHeaderView->setSectionResizeMode(QHeaderView::ResizeToContents);
 #endif
 	pHeaderView->hide();
 
-	QTreeWidget::setItemDelegate(new synthv1widget_programs_item_delegate(this));
+	QTreeWidget::setItemDelegate(new ItemDelegate(this));
 
 	QObject::connect(this,
 		SIGNAL(itemChanged(QTreeWidgetItem *, int)),
@@ -237,7 +265,7 @@ void synthv1widget_programs::loadPrograms ( synthv1_programs *pPrograms )
 	QTreeWidget::clear();
 
 	QList<QTreeWidgetItem *> items;
-	QTreeWidgetItem *pCurrentItem = NULL;
+	QTreeWidgetItem *pCurrentItem = nullptr;
 	const synthv1_programs::Banks& banks = pPrograms->banks();
 	synthv1_programs::Banks::ConstIterator bank_iter = banks.constBegin();
 	const synthv1_programs::Banks::ConstIterator& bank_end = banks.constEnd();
@@ -342,8 +370,8 @@ void synthv1widget_programs::addProgramItem (void)
 QTreeWidgetItem *synthv1widget_programs::newBankItem (void)
 {
 	QTreeWidgetItem *pItem = QTreeWidget::currentItem();
-	QTreeWidgetItem *pBankItem = (pItem ? pItem->parent() : NULL);
-	if (pBankItem == NULL)
+	QTreeWidgetItem *pBankItem = (pItem ? pItem->parent() : nullptr);
+	if (pBankItem == nullptr)
 		pBankItem = pItem;
 
 	int iBank = 0;
@@ -362,7 +390,7 @@ QTreeWidgetItem *synthv1widget_programs::newBankItem (void)
 		if (iBankData < pBankItem->data(0, Qt::UserRole).toInt())
 			break;
 		if (++iBankData > 16383)
-			return NULL;
+			return nullptr;
 	}
 
 	pBankItem = new QTreeWidgetItem(QStringList()
@@ -379,18 +407,18 @@ QTreeWidgetItem *synthv1widget_programs::newBankItem (void)
 QTreeWidgetItem *synthv1widget_programs::newProgramItem (void)
 {
 	QTreeWidgetItem *pItem = QTreeWidget::currentItem();
-	QTreeWidgetItem *pBankItem = (pItem ? pItem->parent() : NULL);
-	QTreeWidgetItem *pProgItem = NULL;
-	if (pBankItem == NULL)
+	QTreeWidgetItem *pBankItem = (pItem ? pItem->parent() : nullptr);
+	QTreeWidgetItem *pProgItem = nullptr;
+	if (pBankItem == nullptr)
 		pBankItem = pItem;
 	else
 		pProgItem = pItem;
-	if (pBankItem == NULL)
+	if (pBankItem == nullptr)
 		pBankItem = QTreeWidget::topLevelItem(0);
-	if (pBankItem == NULL)
+	if (pBankItem == nullptr)
 		pBankItem = newBankItem();
-	if (pBankItem == NULL)
-		return NULL;
+	if (pBankItem == nullptr)
+		return nullptr;
 
 	const int iBankData
 		= pBankItem->data(0, Qt::UserRole).toInt();
@@ -411,7 +439,7 @@ QTreeWidgetItem *synthv1widget_programs::newProgramItem (void)
 		if (iProgData < pProgItem->data(0, Qt::UserRole).toInt())
 			break;
 		if (++iProgData > 127)
-			return NULL;
+			return nullptr;
 	}
 
 	pProgItem = new QTreeWidgetItem(QStringList()
@@ -484,14 +512,14 @@ void synthv1widget_programs::itemChangedSlot ( QTreeWidgetItem *pItem, int )
 
 void synthv1widget_programs::itemExpandedSlot ( QTreeWidgetItem *pItem )
 {
-	if (pItem->parent() == NULL)
+	if (pItem->parent() == nullptr)
 		pItem->setIcon(0, QIcon(":/images/presetBankOpen.png"));
 }
 
 
 void synthv1widget_programs::itemCollapsedSlot ( QTreeWidgetItem *pItem )
 {
-	if (pItem->parent() == NULL)
+	if (pItem->parent() == nullptr)
 		pItem->setIcon(0, QIcon(":/images/presetBank.png"));
 }
 
